@@ -5,6 +5,6 @@ from .. import Matcher
 
 class _be_callable(Matcher):
     def _match(self, subject):
-        return callable(subject)
+        return callable(subject), []
 
 be_callable = _be_callable()
